package net.wanji.opt.dto.export.utils;

import com.alibaba.excel.annotation.ExcelProperty;
import lombok.Data;
import lombok.extern.slf4j.Slf4j;
import net.wanji.opt.dto.export.LaneMapping;
import net.wanji.opt.vo.TableQueryVO;

import java.lang.reflect.Field;
import java.util.ArrayList;
import java.util.List;
import java.util.Map;

/**
 * 车道级数据导出元素
 */
@Slf4j
@Data
public class DynamicExportLaneDataElement {
    private List<DynamicField> fields = new ArrayList<>();

    @Data
    public static class DynamicField {
        @ExcelProperty
        private String fieldName;

        @ExcelProperty
        private Object fieldValue;

        public DynamicField(String fieldName, Object fieldValue) {
            this.fieldName = fieldName;
            this.fieldValue = fieldValue;
        }
    }

    /**
     * 提取数据元素的指定字段值，并转换为动态导出元素
     *
     * @param element        数据元素
     * @param selectedFields 选中的字段
     * @param fieldMapping   字段映射
     * @param clazz          数据元素的类
     * @return
     */
    public static DynamicExportLaneDataElement fromCycleDataElement(Class clazz, Object element, List<String> selectedFields, Map<String, String> fieldMapping) {
        DynamicExportLaneDataElement dynamicElement = new DynamicExportLaneDataElement();
        for (String fieldName : selectedFields) {
            String mappedFieldName = fieldMapping.get(fieldName);
            if (mappedFieldName != null) {
                try {
                    Field field = clazz.getDeclaredField(mappedFieldName);
                    field.setAccessible(true);
                    //提取@ExcelProperty("方向名称")注解的字段值
                    ExcelProperty excelProperty = field.getAnnotation(ExcelProperty.class);
                    if (excelProperty != null) {
                        if (field.get(element) == null) {
                            dynamicElement.getFields().add(new DynamicField(excelProperty.value()[0], "0"));
                        } else {
                            dynamicElement.getFields().add(new DynamicField(excelProperty.value()[0], field.get(element)));
                        }
                    } else {
                        dynamicElement.getFields().add(new DynamicField(fieldName, field.get(element)));
                    }
                } catch (Exception e) {
                    log.error("Failed to get field value for field: " + mappedFieldName, e);
                }
            }
        }
        return dynamicElement;
    }
}
