package net.wanji.opt.dto.export.utils;

import com.alibaba.excel.metadata.Head;
import com.alibaba.excel.metadata.data.CellData;
import com.alibaba.excel.write.handler.WriteHandler;
import com.alibaba.excel.write.metadata.holder.WriteSheetHolder;
import com.alibaba.excel.write.metadata.holder.WriteTableHolder;
import com.alibaba.excel.write.metadata.holder.WriteWorkbookHolder;
import org.apache.poi.ss.usermodel.Cell;
import org.apache.poi.ss.usermodel.Row;
import org.apache.poi.ss.usermodel.Sheet;

import java.util.List;

public class DynamicFieldWriteHandler implements WriteHandler {

    private final List<String> headerList;

    public DynamicFieldWriteHandler(List<String> headerList) {
        this.headerList = headerList;
    }

    public void beforeSheetCreate(WriteWorkbookHolder writeWorkbookHolder, WriteSheetHolder writeSheetHolder) {
        // 创建表头
        Sheet sheet = writeSheetHolder.getSheet();
        Row headRow = sheet.createRow(0);
        for (int i = 0; i < headerList.size(); i++) {
            Cell cell = headRow.createCell(i);
            cell.setCellValue(headerList.get(i));
        }
    }

    public void afterCellDispose(WriteSheetHolder writeSheetHolder, WriteTableHolder writeTableHolder, List<CellData> cellDataList, Cell cell, Head head, Integer relativeRowIndex, Boolean isHead) {
        if (isHead) {
            return;
        }

        DynamicExportLaneDataElement dataElement = (DynamicExportLaneDataElement) cellDataList.get(0).getData();
        List<DynamicExportLaneDataElement.DynamicField> fields = dataElement.getFields();

        Sheet sheet = writeSheetHolder.getSheet();
        Row row = sheet.getRow(cell.getRowIndex());
        for (int i = 0; i < fields.size(); i++) {
            Cell fieldCell = row.createCell(i);
            fieldCell.setCellValue(fields.get(i).getFieldValue().toString());
        }
    }
}
